@@ -85,7 +85,7 @@
 #'
 #' @export lmCombine
 lmCombine <- function(data, ic=c("AICc","AIC","BIC","BICc"), bruteforce=FALSE, silent=TRUE,
-                      distribution=c("dnorm","dlogis","dlaplace","dalaplace","ds","dt",
+                      distribution=c("dnorm","dlaplace","ds","dgnorm","dlogis","dt","dalaplace",
                                      "dfnorm","dlnorm","dllaplace","dls","dbcnorm","dinvgauss",
                                      "dpois","dnbinom",
                                      "plogis","pnorm"),
@@ -94,10 +94,12 @@ lmCombine <- function(data, ic=c("AICc","AIC","BIC","BICc"), bruteforce=FALSE, s
     cl <- match.call();
     cl$formula <- as.formula(paste0("`",colnames(data)[1],"`~ ."));
 
-    #### This is temporary and needs to be removed at some point! ####
-    bruteforce[] <- depricator(bruteforce, list(...));
-
     ellipsis <- list(...);
+    # Only likelihood is supported by the function
+    loss <- "likelihood";
+    if(is.null(ellipsis$loss)){
+       ellipsis$loss <- loss;
+    }
 
     # If they asked for parallel, make checks and try to do that
     if(parallel){
@@ -195,19 +197,8 @@ lmCombine <- function(data, ic=c("AICc","AIC","BIC","BICc"), bruteforce=FALSE, s
     # }
 
     # Define the function of IC
-    ic <- ic[1];
-    if(ic=="AIC"){
-        IC <- AIC;
-    }
-    else if(ic=="AICc"){
-        IC <- AICc;
-    }
-    else if(ic=="BIC"){
-        IC <- BIC;
-    }
-    else if(ic=="BICc"){
-        IC <- BICc;
-    }
+    ic <- match.arg(ic);
+    IC <- switch(ic,"AIC"=AIC,"BIC"=BIC,"BICc"=BICc,AICc);
 
     # Define what function to use in the estimation
     if(useALM){
